/*
This folder contains implementation of various initial conditions (for the gUPPEcore
simulator), which contain (apodized) Airy-function profile in time (airy pulses), 
space (Airy beams), or both. Radially symmetric solutions are implemented as well.

The corresponding header files, one for each type of the pulsed beam, contain
the definitions of the initial condition functions, as well as of the list
of named parameters for each.

Naming convention: see user_addons.cc

author: Paris Panagiotopoulos, 2014
*/

#include<uppe_params_incond.h>  
#include<uppe_params_response.h>
#include<uppe_params_operators.h>  
#include<uppe_params_domain.h>  
#include<domain.h>  

// include here all your user-defined class headers

// initial conditions:
#include"rAiry.h"	/* rAiry in space,      Gaussian in time  */
#include"rtAiryL.h"	/* rAiry in space,      Airy in time Left */
#include"rtAiryR.h"	/* rAiry in space,     Airy in time Right */
#include"rttAiry.h"	/* rAiry in space,    Double Airy in time */
#include"tAiryL.h"	/* Gaussian in space,   Airy in time Left */
#include"tAiryR.h"	/* Gaussian in space,  Airy in time Right */
#include"ttAiry.h"	/* Gaussian in space, Double Airy in time */

// medium responses:
// nonthig here this time


// operators:
// none here

// the following functions serve to identify classes by their names

// user-defined initial condition classes:
template<>
UPPEinitial_condition* NameIdentifiedClassPtr_usr<UPPEinitial_condition>(char const* s) {
  // this is how you assign an ID string to a class
  _getVirtualClassPtr(s,"SpatialRingAiry", rAiry);
  _getVirtualClassPtr(s,"SpatioTemporalRingAiryLeft", rtAiryL);
  _getVirtualClassPtr(s,"SpatioTemporalRingAiryRight", rtAiryR);
  _getVirtualClassPtr(s,"SpatioTemporalRingAiryDouble", rttAiry);
  _getVirtualClassPtr(s,"TemporalAiryLeft", tAiryL);
  _getVirtualClassPtr(s,"TemporalAiryRight", tAiryR);
  _getVirtualClassPtr(s,"TemporalAiryDouble", ttAiry);
  return(0);
}


// user-defined medium response classes:
template <>
UPPE_params_nlresponse* NameIdentifiedClassPtr_usr<UPPE_params_nlresponse>(char const* s) {
  // in this case we have no user-defined medium responses
  return(0);
}


// user-defined operator classes:
template <>
UPPE_operator* NameIdentifiedClassPtr_usr<UPPE_operator>(char const* s) {
  // in this case we have no user-defined operators
  return(0);
}


// user-defined SpatialDomain classes:
template <>
gUPPE_Domain_Spatial* NameIdentifiedClassPtr_usr<gUPPE_Domain_Spatial>(char const* s) {
  // in this case we have no user-defined SpatialDomains
  return(0);
}


Params_Domain_UserDefined* GetClassPtr_Params_Domain_UserDefined(char const* s) {
  // in this case we have no user-defined SpatialDomain-Parameters
  return(0);
}

